pub struct CheckConstraint {
pub id: u16,
pub name: String,
pub expr: CheckExpr,
}Expand description
A CHECK constraint: the row is rejected when expr evaluates to False
(SQL three-valued logic: Unknown/True both pass).
Fields
id: u16name: Stringexpr: CheckExprTrait Implementations
Sourceimpl Clone for CheckConstraint
impl Clone for CheckConstraint
Sourcefn clone(&self) -> CheckConstraint
fn clone(&self) -> CheckConstraint
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CheckConstraint
impl Debug for CheckConstraint
Sourceimpl<'de> Deserialize<'de> for CheckConstraint
impl<'de> Deserialize<'de> for CheckConstraint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CheckConstraint
impl PartialEq for CheckConstraint
Sourcefn eq(&self, other: &CheckConstraint) -> bool
fn eq(&self, other: &CheckConstraint) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CheckConstraint
impl Serialize for CheckConstraint
impl StructuralPartialEq for CheckConstraint