pub struct UniqueConstraint {
pub id: u16,
pub name: String,
pub columns: Vec<u16>,
}Expand description
A multi-column uniqueness constraint (beyond the single-column PRIMARY_KEY
flag). Enforced via an existence scan against the read snapshot plus
WriteKey::Unique registration at commit (first-committer-wins).
Fields
id: u16name: Stringcolumns: Vec<u16>Trait Implementations
Sourceimpl Clone for UniqueConstraint
impl Clone for UniqueConstraint
Sourcefn clone(&self) -> UniqueConstraint
fn clone(&self) -> UniqueConstraint
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UniqueConstraint
impl Debug for UniqueConstraint
Sourceimpl<'de> Deserialize<'de> for UniqueConstraint
impl<'de> Deserialize<'de> for UniqueConstraint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for UniqueConstraint
impl PartialEq for UniqueConstraint
Sourcefn eq(&self, other: &UniqueConstraint) -> bool
fn eq(&self, other: &UniqueConstraint) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for UniqueConstraint
impl Serialize for UniqueConstraint
impl StructuralPartialEq for UniqueConstraint